@@ -150,10 +150,8 @@ bcdc_query_geodata.bcdc_record <- function(record, crs = 3005) {
     wfs_resource$url
   ))
 
-  if (layer_name != wfs_resource$object_name) {
-    warning("The name of the object available through the web service ",
-            "differs from the warehouse object name. You may be accessing ",
-            "a simplified view of the data - see the catalogue record for details.",
+  if (grepl("_SP?G$", layer_name)) {
+    message("You are accessing a simplified view of the data - see the catalogue record for details.",
             call. = FALSE)
   }
 
